// OscDrawingDemo 

import oscP5.*;
import netP5.*;

OscP5 oscP5;

int CANVAS_WIDTH = 600;
int CANVAS_HEIGHT = 600;

float eX, eY;

String configFile      = "config.txt";
String touchOSCAddress = "0.0.0.0";
String localOSCAddress = "0.0.0.0";
int    touchOSCPort    = 8081;
int    localOSCPort    = 8001;

float[] rectScale      = {0.0, 1.0, 1.0};
int[]   rectTranslate  = {0, 1, 1, 1, 1, 1, 1};



void loadData(){

  String defaultValues[] = split("127.0.0.1:8081\n127.0.0.1:8001", "\n");

  try {
    String lines[] = loadStrings(configFile);

    for (int i=0; i < lines.length; i++) {
      defaultValues[i] =  lines[i]; 
      println("DEBUG lines["+i+"] = " + lines[i] ); // DEBUG
    }
  } catch(Exception e) {
    println("Error loading data from '" + configFile + "'");
    e.printStackTrace();
  }

  int i = 0;

  String[] localValues = split(defaultValues[i], ":");  
  String[] clientValues = split(defaultValues[i], ":"); i++;

  
  localOSCAddress = trim(localValues[0]);   
  localOSCPort    = int(trim(localValues[1]));

  touchOSCAddress = trim(clientValues[0]);   
  touchOSCPort    = int(trim(clientValues[1]));

}



void setup() {
  size(CANVAS_WIDTH, CANVAS_HEIGHT);
  loadData();
  oscP5 = new OscP5(this, localOSCAddress, localOSCPort);
}


void rect1(){
  fill(120, 255, 23);
  rect(rectTranslate[1], rectTranslate[2], rectScale[1], rectScale[1] );
}

void rect2(){
  fill(3, 10, 200);       
  rect(rectTranslate[4], rectTranslate[5], rectScale[2], rectScale[2] );
}

void draw() {
  background(102);
  rect1();
  rect2();
}



void oscEvent(OscMessage theOscMessage) {
  /* print the address pattern and the typetag of the received OscMessage */
  print("### received an osc message.");
  print(" addrpattern: "+theOscMessage.addrPattern());
  println(" typetag: "+theOscMessage.typetag());
  println(" arguments: "+theOscMessage.arguments()[0].toString());

  float value = (Float)theOscMessage.arguments()[0];

  /*

     

     All the TouchOSC messages send floats.  Even the momentary switches,
     which send 1.0 or 0.0

     We're using layout Mix2.  The main screen is shows controls for two
     channels.  

     [] []                   /1/toggle/1   /1/toggle/3
     O  [] []  O    /1/rotary1  /1/toggle/2   /1/toggle/4   /1/rotary4
     O  || ||  O    /1/rotary2  /1/fader1     /1/fader2     /1/rotary5  
     O  || ||  O    /1/rotary3                              /1/rotary5
     [] [] || || [] [] /1/push1  /1/push2                      /1/push3  /1/push4

     [_______|_______]                     /1/fader/3



     We map left side to rect1, right side to rect2



   */

  int control = 2;
  String[] parts = split(theOscMessage.addrPattern(), "/");
  println("parts[control]: '" + parts[control]  + "'" );


  // we should have an integer, for the layout, and a string, for the controll 
  String[] res;


  String reRotary = "(rotary)(.)";
  String reToggle = "(toggle)(.)";
  String rePush   = "(push)(.)";
  String reFader  = "(fader)(.)";

 

  res = match(parts[control], reFader);
  if (res != null) {
    println("FADER for " + res[2] );
      println("Set scaling for rect " + int(res[2]) );
    rectScale[ int(res[2]) ] = map(value, 0.0, 1.0, 0.1, CANVAS_WIDTH);
    return;
  } 

  res = match(parts[control], reRotary);

  if (res != null) {

    int v = (int) map(value, 0.0, 1.0, 0, CANVAS_WIDTH);
    println("ROTARY for " + int(res[2]) + "; v = " + v );

     println("Set  for rect " + int(res[2]) );
    rectTranslate[ int(res[2]) ] = v;
    println( "++++++ rectTranslate[ " + int(res[2]) + " ] = " + rectTranslate[ int(res[2]) ] );
    return;
  } 

}

